Learn R Programming

locStra (version 1.9)

bed_fastCovEVs: Computation of the k leading eigenvectors of the covariance matrix directly from a bed+bim+fam file.

Description

Computation of the k leading eigenvectors of the covariance matrix directly from a bed+bim+fam file.

Usage

bed_fastCovEVs(f, k, q = 2)

Arguments

f

The filename of the bed file (including its extension). The bim and fam files need to be in the same folder and have the same base filename.

k

The number of leading eigenvectors.

q

The number of power iteration steps (default is q=2).

Value

The k leading eigenvectors of the covariance matrix of m as a column matrix.

References

R Core Team (2014). R: A Language and Environment for Statistical Computing. R Foundation for Stat Comp, Vienna, Austria.

N. Halko, P.G. Martinsson, and J.A. Tropp (2011). Finding Structure with Randomness: Probabilistic Algorithms for Constructing Approximate Matrix Decompositions. SIAM Review: 53(2), pp. 217--288.

F. Prive, M. Blum, H. Aschard, B.J. Vilhjalmsson (2022). bigsnpr: Analysis of Massive SNP Arrays. https://cran.r-project.org/package=bigsnpr

Examples

Run this code
# NOT RUN {
require(locStra)

# }

Run the code above in your browser using DataLab