Computation of the k leading eigenvectors of the genomic relationship matrix, defined in Yang et al. (2011), directly from a bed+bim+fam file.
bed_fastGrmEVs(f, k, robust = TRUE, q = 2)The filename of the bed file (including its extension). The bim and fam files need to be in the same folder and have the same base filename.
The number of leading eigenvectors.
Flag to indicate if the classic (robust=FALSE) or robust (robust=TRUE) version of the genomic relationship matrix is desired. Default is robust=TRUE.
The number of power iteration steps (default is q=2).
The k leading eigenvectors of the genomic relationship matrix of m as a column matrix.
Yang J, Lee SH, Goddard ME, Visscher PM (2011). GCTA: a tool for genome-wide complex trait analysis. Am J Hum Genet, 88(1):76-82.
N. Halko, P.G. Martinsson, and J.A. Tropp (2011). Finding Structure with Randomness: Probabilistic Algorithms for Constructing Approximate Matrix Decompositions. SIAM Review: 53(2), pp. 217--288.
F. Prive, M. Blum, H. Aschard, B.J. Vilhjalmsson (2022). bigsnpr: Analysis of Massive SNP Arrays. https://cran.r-project.org/package=bigsnpr
# NOT RUN {
require(locStra)
# }
Run the code above in your browser using DataLab